@@ -195,7 +195,7 @@ class BinaryTransformer(BaseEstimator, TransformerMixin):
             transforms.append(binary)
         return pd.concat(transforms, axis=1).mask(pd.isnull(X)).astype('O')
 
-class UnknownCategoryTransformer(BaseEstimator, TransformerMixin):
+class UnknownToNanTransformer(BaseEstimator, TransformerMixin):
     """Sets unknown categories to nan."""
 
     def fit(self, X, y = None):
